@@ -62,7 +62,7 @@ def notice_h(fmt, lst):
         warn_msg = fmt % lst
     except TypeError:
         warn_msg = fmt
-    logger.warning('GEOS_NOTICE: %s\n' % warn_msg)
+    logger.warning('GEOS_NOTICE: %s\n', warn_msg)
 notice_h = NOTICEFUNC(notice_h)
 
 ERRORFUNC = CFUNCTYPE(None, c_char_p, c_char_p)
@@ -74,7 +74,7 @@ def error_h(fmt, lst):
         err_msg = fmt % lst
     except TypeError:
         err_msg = fmt
-    logger.error('GEOS_ERROR: %s\n' % err_msg)
+    logger.error('GEOS_ERROR: %s\n', err_msg)
 error_h = ERRORFUNC(error_h)
 
 # #### GEOS Geometry C data structures, and utility functions. ####
